@@ -1,11 +1,12 @@
-from .printer import Printer
-from .table import Table
+from .borders import Borders, BorderDfn
+from .card import Card
 from .fill import Fill
 from .flex import Flex
-from .card import Card
-from . import context
 from .hr import HR
 from .line import Line
-from .text import Text
 from .pretty import pretty
+from .printer import Printer
+from .table import Table, CellDfn
+from .text import Text
+from . import context
 print = Printer()
